@@ -24,38 +24,38 @@ extern "C" {
 /**
  * XSLT_DEFAULT_VERSION:
  *
- * The default version of XSLT supported
+ * The default version of XSLT supported.
  */
 #define XSLT_DEFAULT_VERSION     "1.0"
 
 /**
  * XSLT_DEFAULT_VENDOR:
  *
- * The XSLT "vendor" string for this processor
+ * The XSLT "vendor" string for this processor.
  */
 #define XSLT_DEFAULT_VENDOR      "libxslt"
 
 /**
  * XSLT_DEFAULT_URL:
  *
- * The XSLT "vendor" URL for this processor
+ * The XSLT "vendor" URL for this processor.
  */
 #define XSLT_DEFAULT_URL         "http://xmlsoft.org/XSLT/"
 
 /**
  * XSLT_NAMESPACE:
  *
- * The XSLT specification namespace
+ * The XSLT specification namespace.
  */
 #define XSLT_NAMESPACE ((xmlChar *) "http://www.w3.org/1999/XSL/Transform")
 
 /**
  * LIBXSLT_PUBLIC:
  *
- * Macro used on Windows to tag public identifiers from shared libraries
+ * Macro used on Windows to tag public identifiers from shared libraries.
  */
 #if !defined LIBXSLT_PUBLIC
-#if defined _MSC_VER && !defined IN_LIBXSLT && !defined LIBXSLT_STATIC
+#if (defined (__CYGWIN__) || defined _MSC_VER) && !defined IN_LIBXSLT && !defined LIBXSLT_STATIC
 #define LIBXSLT_PUBLIC __declspec(dllimport)
 #else
 #define LIBXSLT_PUBLIC 
@@ -65,33 +65,33 @@ extern "C" {
 /**
  * xsltMaxDepth:
  *
- * This value is used to detect templates loops
+ * This value is used to detect templates loops.
  */
 LIBXSLT_PUBLIC extern int xsltMaxDepth;
 
 /**
  * xsltEngineVersion:
  *
- * The version string for libxslt
+ * The version string for libxslt.
  */
 LIBXSLT_PUBLIC extern const char *xsltEngineVersion;
 
 /**
  * xsltLibxsltVersion:
  *
- * The version of libxslt compiled
+ * The version of libxslt compiled.
  */
 LIBXSLT_PUBLIC extern const int xsltLibxsltVersion;
 
 /**
  * xsltLibxmlVersion:
  *
- * The version of libxml libxslt was compiled against
+ * The version of libxml libxslt was compiled against.
  */
 LIBXSLT_PUBLIC extern const int xsltLibxmlVersion;
 
 /*
- * Global cleanup function
+ * Global cleanup function.
  */
 void	xsltCleanupGlobals	(void);
 
